package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmExamineRoleTarget;

/**
 * 时户数考核规则分级Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-30
 */
public interface PdmExamineRoleTargetMapper
{
    /**
     * 查询时户数考核规则分级
     *
     * @param id 时户数考核规则分级主键
     * @return 时户数考核规则分级
     */
    public PdmExamineRoleTarget selectPdmExamineRoleTargetById(Long id);

    /**
     * 查询时户数考核规则分级列表
     *
     * @param pdmExamineRoleTarget 时户数考核规则分级
     * @return 时户数考核规则分级集合
     */
    public List<PdmExamineRoleTarget> selectPdmExamineRoleTargetList(PdmExamineRoleTarget pdmExamineRoleTarget);

    /**
     * 新增时户数考核规则分级
     *
     * @param pdmExamineRoleTarget 时户数考核规则分级
     * @return 结果
     */
    public int insertPdmExamineRoleTarget(PdmExamineRoleTarget pdmExamineRoleTarget);

    /**
     * 修改时户数考核规则分级
     *
     * @param pdmExamineRoleTarget 时户数考核规则分级
     * @return 结果
     */
    public int updatePdmExamineRoleTarget(PdmExamineRoleTarget pdmExamineRoleTarget);

    /**
     * 删除时户数考核规则分级
     *
     * @param id 时户数考核规则分级主键
     * @return 结果
     */
    public int deletePdmExamineRoleTargetById(Long id);

    /**
     * 批量删除时户数考核规则分级
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmExamineRoleTargetByIds(Long[] ids);
}
